@@ -7,7 +7,8 @@ import backoff
 import json
 import requests
 import urllib.parse
-import logging
+from cdislogging import get_logger
+
 import sys
 import time
 
@@ -20,6 +21,8 @@ INDEX_MANIFEST_JOB = "index-object-manifest"
 DOWNLOAD_MANIFEST_JOB = "download-indexd-manifest"
 MERGE_MANIFEST_JOB = "merge-manifests"
 
+logging = get_logger("__name__")
+
 
 class Gen3Jobs:
     """
