@@ -5,7 +5,6 @@ import aiohttp
 import backoff
 from datetime import datetime
 import requests
-import logging
 import json
 import os
 from urllib.parse import urlparse
@@ -29,6 +28,10 @@ from gen3.tools.indexing.manifest_columns import (
     PREV_GUID_COLUMN_NAMES,
 )
 
+from cdislogging import get_logger
+
+logging = get_logger("__name__")
+
 
 PACKAGE_CONTENTS_STANDARD_KEY = "package_contents"
 PACKAGE_CONTENTS_SCHEMA = {
@@ -438,19 +441,6 @@ class Gen3Metadata:
 
         return response.json()
 
-    def create_object(self, file_name, authz, metadata=None, aliases=None):
-        url = self.endpoint + "/objects"
-        body = {
-            "file_name": file_name,
-            "authz": authz,
-            "metadata": metadata,
-            "aliases": aliases,
-        }
-        response = requests.post(url, json=body, auth=self._auth_provider)
-        raise_for_status(response)
-        data = response.json()
-        return data["guid"], data["upload_url"]
-
     def _prepare_metadata(self, metadata, indexd_doc):
         """
         Validate and generate the provided metadata for submission to the metadata
