@@ -1,14 +1,19 @@
+import asyncio
 from jsonschema import Draft4Validator
-import logging
 import sys
 import re
 import requests
+import os
 
 from urllib.parse import urlunsplit
 from urllib.parse import urlencode
 from urllib.parse import urlsplit
 from urllib.parse import parse_qs
 
+from cdislogging import get_logger
+
+logging = get_logger("__name__")
+
 
 UUID_FORMAT = (
     r"^.*[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$"
@@ -20,6 +25,28 @@ URL_FORMAT = r"^.*$"
 AUTHZ_FORMAT = r"^.*$"
 
 
+def get_or_create_event_loop_for_thread():
+    """
+    Asyncio helper function to attempt to get a currently running loop and
+    if there isn't one in the thread, create one and set it so future calls
+    get the same event loop.
+    """
+    try:
+        loop = asyncio.get_running_loop()
+    except RuntimeError:
+        # no loop for this thread, so create one
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+    except AttributeError:
+        # handle older versions of asyncio for previous versions of Python,
+        # specifically this allows Python 3.6 asyncio to get a loop
+        loop = asyncio._get_running_loop()
+        if not loop:
+            loop = asyncio.get_event_loop()
+
+    return loop
+
+
 def raise_for_status(response):
     try:
         response.raise_for_status()
@@ -183,6 +210,6 @@ def get_urls(raw_urls_string):
 DEFAULT_BACKOFF_SETTINGS = {
     "on_backoff": log_backoff_retry,
     "on_giveup": log_backoff_giveup,
-    "max_tries": 3,
+    "max_tries": os.environ.get("GEN3SDK_MAX_RETRIES", 3),
     "giveup": exception_do_not_retry,
 }
